Struct vade_evan_substrate::TypeOptions
source · [−]Expand description
Message passed to vade containing the desired did implementation. Does not perform action if type does not indicate did type.
Fields
type: Option<String>Trait Implementations
sourceimpl<'de> Deserialize<'de> for TypeOptions
impl<'de> Deserialize<'de> for TypeOptions
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl Serialize for TypeOptions
impl Serialize for TypeOptions